@@ -14,6 +14,8 @@ import hildon, osso
 
 # third-party modules
 import gtk, dbus, pango
+from PySide.QtCore import *
+
 
 # program modules
 from vertsms import config, sms, pygobject
@@ -27,6 +29,8 @@ class VertSMS():
     last_key_pressed = None
     elapsed_time = 0
     last_update = time.time()
+    app = QCoreApplication(sys.argv)
+
     
 
     def __init__(self):
